pub enum Mode {
None = 0,
Diagonal = 1,
BlockDiagonal = 2,
Diagonals = 3,
Full = 4,
}Expand description
Mode of tiled covariance matrix or mode of tile as part of tilemap.
Valid modes of tile as part of tilemap are:
Self::Nonefor an unset tile,Self::Diagonalfor a diagonal tile, andSelf::Fullfor a block tile.
Default is Self::None.
Variants
None = 0
Mode of unset tile.
Diagonal = 1
Mode of covariance matrix with diagonal tiles on its diagonal (or mode of diagonal tile).
BlockDiagonal = 2
Mode of covariance matrix with diagonal or block tiles on its diagonal.
Diagonals = 3
Mode of covariance matrix with diagonal tiles all over.
Full = 4
Mode of covariance matrix with diagonal or block tiles all over (or mode of block tile).